# aniinfo 
### cli tool for searching animes and animes info 

<hr>

# installation  

`
pip3 install aniinfo
`
### or

`
git clone https://github.com/R4YISH/aniinfo  &&
cd aniinfo  &&
pip3 install .  
`

<hr>

# usage

aniinfo -a [anime-name] --page [page-num]  
aniinfo -m [manga-name] --page [page-num]  
aniinfo -c [characters-name] --page [page-num]  

<hr>

# config

paste [this](https://raw.githubusercontent.com/R4YISH/aniinfo/main/aniinfo/data/config.json) to ~/.config/aniinfo/config.json
and config it

<hr>

# example   

![searching anime](https://i.imgur.com/k9Mnvlj.png)   


<hr>



